from adasher.data_utils.__util import DF, Period


def time_period(dt1, dt2, name):
    return Period(dt1, dt2, name)

